@@ -397,7 +397,7 @@ crawlWrap<-function(obsData, timeStep=1, ncores, retryFits = 0,
   predData <- 
     foreach(i = convFits, .export="crwPredict", .combine = rbind, .errorhandling="remove") %dopar% {
       pD<-crawl::crwPredict(model_fits[[i]], predTime=predTime[[i]])
-      pD[[Time.name]][which(pD$locType=="p")]<-predTime[[i]]
+      pD[[Time.name]][which(pD$locType=="p")]<-predTime[[i]][predTime[[i]]>=min(model_fits[[i]]$data[[Time.name]])]
       if(!fillCols){
         for(j in names(pD)[names(pD) %in% names(ind_data[[i]])]){
           if(!(j %in% c(Time.name,"ID",coord))){
